@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -34,10 +34,11 @@ public:
     KWallet::Wallet *wallet();
 
     void closeWallet();
-private Q_SLOTS:
+private:
     void slotWalletClosed();
 
 private:
+    Q_DISABLE_COPY(SieveServerSettings)
     explicit SieveServerSettings(QObject *parent = nullptr);
     friend class SieveServerSettingsPrivate;
     KWallet::Wallet *mWallet = nullptr;
